@@ -28,6 +28,9 @@ pub mod node;
 /// Generate and validate proofs using the merkle tally tree.
 pub mod proof;
 
+/// Serialize nodes and proofs
+pub mod serialize;
+
 /// Functions for tallying votes
 pub mod tally;
 
