@@ -8,8 +8,15 @@ use crate::proof::{Proof, ProofBranch};
 use crate::tally::{has_one_vote, TallyList};
 use crate::{Validation, VoteReference};
 
-type InclusionProof = Option<Proof>;
-type ExclusionProof = Option<(Option<Proof>, Option<Proof>)>;
+/**
+ * A proof that a node exists in a merkle tally tree.
+ */
+pub type InclusionProof = Option<Proof>;
+
+/**
+ * A proof that a node does not exist in a merkle tally tree.
+ */
+pub type ExclusionProof = Option<(Option<Proof>, Option<Proof>)>;
 
 /// Create proof of a vote references' existence or non-existance in a merkle
 /// tree.
